@@ -33,9 +33,10 @@
 #  define AKONADIPRIVATE_DEPRECATED_NO_EXPORT AKONADIPRIVATE_NO_EXPORT AKONADIPRIVATE_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define AKONADIPRIVATE_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef AKONADIPRIVATE_NO_DEPRECATED
+#    define AKONADIPRIVATE_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
